import csv
from io import StringIO, BytesIO
from typing import Any


def csv_loads(line: bytes):
    return next(csv.reader(StringIO(line.decode())))


def csv_dumps(row: list) -> bytes:
    io = StringIO(newline="")
    writer = csv.writer(io)
    writer.writerow(row)
    io.seek(0)
    return io.read().rstrip().encode()


def str_dumps(x: Any):
    return str(x).encode()


import os

from setuptools import setup, find_packages

with open(os.path.join(os.path.dirname(os.path.abspath(__file__)), "README.md"), "r", encoding="utf-8") as f:
    long_description = f.read()

setup(name="shmr",
      version='1.0.3',
      packages=find_packages(),
      description="A set of map-reduce high-order functions to use with parallel or xargs",
      long_description=long_description,
      long_description_content_type='text/markdown',
      author="Binh Vu",
      author_email="binh@toan2.com",
      url="https://github.com/binh-vu/shmr",
      python_requires='>3.6',
      license="MIT",
      install_requires=['orjson', 'tqdm', 'docstring-parser>=0.6', 'fastnumbers'],
      package_data={'': ['*.so', '*.pyd']})
